library(ggplot2)
library(plyr)

SA11_diff_exp <- read.table("./SA11_expression_barplot.txt", sep="\t", header=TRUE)
SA11_diff_exp[3] <- -SA11_diff_exp[3]

SA11_diff_exp$Gene_name.order <- factor(SA11_diff_exp$Gene_name, 
                                        levels = c("SA11v2_04025", "SA11v2_05067", "SA11v2_04036", "SA11v2_01200", 
                                                   "SA11v2_00763", "SA11v2_04522", "SA11v2_02359", "SA11v2_00762", "SA11v2_02360", 
                                                   "SA11v2_05062", "SA11v2_01198", "SA11v2_01199", "SA11v2_05063", "SA11v2_04525",
                                                   "SA11v2_04037", "SA11v2_02358", "SA11v2_04523", "SA11v2_04524", "SA11v2_04527", 
                                                   "SA11v2_02357", "SA11v2_04038", "SA11v2_04526", "SA11v2_04517", "SA11v2_04519", 
                                                   "SA11v2_04521"), ordered = TRUE)

dat1 <- subset(SA11_diff_exp, log2FoldChange >= 0)
dat2 <- subset(SA11_diff_exp, log2FoldChange < 0)



p <- ggplot(data.copies.mL.merged, aes(y=Value, x=Hours, group=interaction(Type, Treatment))) + theme_bw()

ggplot() + 
  geom_bar(data = dat1, aes(x=Gene_name.order, y=log2FoldChange, fill=Plot.name),stat = "identity") +
  geom_errorbar(data = dat1, aes(x=Gene_name.order, ymax = log2FoldChange + lfcSE, 
                                 ymin=log2FoldChange - lfcSE, fill=Plot.name), stat = "identity") +
  geom_text(data = dat1,aes(x=Gene_name.order, y=log2FoldChange, label=baseMean)) +
  geom_bar(data = dat2, aes(x=Gene_name.order, y=log2FoldChange, fill=Plot.name),stat = "identity") + 
  geom_errorbar(data = dat2, aes(x=Gene_name.order, ymax = log2FoldChange + lfcSE, 
                                 ymin=log2FoldChange - lfcSE, fill=Plot.name), stat = "identity") +
  geom_text(data = dat2,aes(x=Gene_name.order, y=log2FoldChange, label=baseMean)) +
  theme_bw()

##### Making base mean bar charts
p <- ggplot(SA11_diff_exp, aes(y=baseMean, x=Gene_name)) + theme_bw()
p + geom_bar(aes(x=Gene_name.order, y= baseMean, fill = Plot.name), stat = "identity") 

